%% Class identification
%% This is a class file for submitting articles to journal Acta Montanistica Slovaca.
%%
%% Created by Ing. Ivan Brezáni {ivan.brezani@tuke.sk}{ivanbrezani@gmail.com}
%% 
%% ----------------------------------------------------------------------------------
%%
%% It may be distributed under the conditions of the LaTeX Project Public
%% License, either version 1.2 of this license or (at your option) any
%% later version.  The latest version of this license is in
%%    http://www.latex-project.org/lppl.txt
%% and version 1.2 or later is part of all distributions of LaTeX
%% version 1999/12/01 or later.

\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvidesClass{actamont}[2010/06/01 LaTeX class for Acta Montanistica Slovaca]

%% Necessary variables for defined options
\newif\if@Final
\newif\if@Special
\newif\if@SK
\newif\if@CZ
\def\@Page{1}
\newif\if@Numbered

\@Finalfalse
\@Specialfalse
\@SKfalse
\@CZfalse
\@Numberedfalse

%% Other variables used
\def\@Journal{Acta Montanistica Slovaca}

%% Options of actamont class
\DeclareOption{final}{\global\@Finaltrue}
\DeclareOption{special}{\global\@Specialtrue}
\DeclareOption{sk}{\global\@SKtrue}
\DeclareOption{cz}{\global\@CZtrue}
\DeclareOption{numberedrefs}{\global\@Numberedtrue}
\DeclareOption{a4paper}{\PassOptionsToClass{a4paper}{article}}
\DeclareOption{twoside}{\PassOptionsToClass{twoside}{article}}
\DeclareOption{10pt}{\PassOptionsToClass{10pt}{article}}
\DeclareOption{onecolumn}{\PassOptionsToClass{onecolumn}{article}}
%\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\DeclareOption*{\ClassWarningNoLine{actamont}{Unknown option `\CurrentOption' specified for 'actamont' class}}

\ExecuteOptions{a4paper,10pt,twoside,onecolumn}
\ProcessOptions

%% This class is based on standard LaTeX article class
%\LoadClass[a4paper,twoside,10pt]{article}
\LoadClass{article}


%% Required packages
\RequirePackage[T1]{fontenc} %% Standard Encoding
\RequirePackage{ifthen} %% Provides if then else commands and usefull tests
\if@Special
	\else\if@SK\RequirePackage[utf8]{inputenc}
	\else
\fi\fi

\if@Special
	\if@SK
	\RequirePackage[utf8]{inputenc}\RequirePackage[slovak]{babel}
	\else\RequirePackage[utf8]{inputenc}
	\else
\fi\fi

\if@Special
	\else\if@CZ\RequirePackage[utf8]{inputenc}
	\else
\fi\fi

\if@Special
	\if@CZ\RequirePackage[utf8]{inputenc}\RequirePackage[czech]{babel}
	\else\RequirePackage[utf8]{inputenc}
\fi\fi

\RequirePackage{caption} %% To make changes to caption formatting possible

\if@Numbered
	\RequirePackage[numbers]{natbib}
	\else\RequirePackage{natbib}
\fi

\RequirePackage{fancyhdr} %% Needed to setup header and footer

\if@Final
	\RequirePackage{lastpage}
	\else
\fi

\RequirePackage{graphicx} %% For graphical inputs (figures)
\RequirePackage{color} %% For use with hyperlinks - blue color
\RequirePackage{hyperref} %% Hyperlinks support

%% Figure and Table environment
\renewenvironment{figure}
               {\def\@currenv{f} \@float{figure}}
               {\end@float}
\renewenvironment{figure*}
               {\def\@currenv{f} \@dblfloat{figure}}
               {\end@dblfloat}
\renewenvironment{table}
               {\def\@currenv{t} \@float{table}}
               {\end@float}
\renewenvironment{table*}
               {\def\@currenv{t} \@dblfloat{table}}
               {\end@dblfloat}
\def\@floatboxreset{\@setminipage\centering} % centered by default
\renewcommand\arraystretch{1.25} % stretch row heights in tables for better readability

%% Captions setup - Times New Roman, 8 pt, italics
\renewcommand{\captionfont}{\fontfamily{ptm}\fontsize{8}{8}\selectfont\it}
\renewcommand{\captionlabelfont}{\fontfamily{ptm}\fontsize{8}{8}\selectfont\it}
\setlength{\captionmargin}{10pt}
\if@Special
	\renewcommand{\figurename}{Obr.}
	\else\renewcommand{\figurename}{Fig.}
\fi

\renewcommand\tablename{Tab.}

\abovecaptionskip=3pt
\belowcaptionskip=3pt

\if@Special
	\newcommand{\Caption}[2]{%
		\ifthenelse{\equal{\@currenv}{f}}{\captionsetup{singlelinecheck=off,justification=centering}\caption{#1\\Fig. \thefigure . #2}}{}
		\ifthenelse{\equal{\@currenv}{t}}{\captionsetup{singlelinecheck=off,justification=centering}\caption{#1\\Tab. \thetable . #2}}{}
	}
\else\fi

%% Hyperlinks to be black, except url and e-mail
\hypersetup{
    colorlinks,%
    citecolor=black,%
    filecolor=black,%
    linkcolor=black,%
    urlcolor=blue,
}

%% Declare basic font sizes commands \normalsize \footnotesize \small to use Times New Roman font and
%% be of desired sizes
\renewcommand{\rmdefault}{ptm}
\renewcommand{\normalsize}{\fontfamily{ptm}\fontsize{10}{12}\selectfont}
\renewcommand{\footnotesize}{\fontfamily{ptm}\fontsize{8}{10}\selectfont}
\renewcommand{\small}{\fontsize{8}{10}\selectfont}
\renewcommand{\baselinestretch}{1} % Line spacing set to 1.0
\renewcommand{\familydefault}{ptm} % Default font set to Times 

%% References command - for use with BiBTeX and to make it possible to change name of section
\if@Numbered
	\bibliographystyle{ieeetr}
	\else\bibliographystyle{model2-names}
\fi
\newcommand{\References}[2]{\ifthenelse{\equal{#1}{\@empty}}{}{\renewcommand{\refname}{#1}} \bibliography{#2} \addcontentsline{toc}{section}{\refname}}
\newcommand{\othertitle}[1]{\def\@OtherTitle{#1}}

%% Hyperreference made easier
\newcommand{\Ref}[2]{\hyperref[#2]{{#1}~\ref*{#2}}}

%% Citations setup to format (Surname 2010) - no comma between author and year
\if@Numbered
	\setcitestyle{numbers}
	\else\bibpunct{(}{)}{;}{a}{}{,}
\fi

%% Redefine \section \subsection and \subsubsection commands (no numbering, sizes, Times New Roman,...)
\renewcommand\section{\@startsection {section}{1}{\z@}%
           {18\p@ \@plus 6\p@ \@minus 3\p@}%
           {9\p@ \@plus 6\p@ \@minus 3\p@}%
           {\fontfamily{ptm}\fontsize{10}{10}\selectfont\bf\centering}}
\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
           {12\p@ \@plus 6\p@ \@minus 3\p@}%
           {3\p@ \@plus 6\p@ \@minus 3\p@}%
           {\fontfamily{ptm}\fontsize{10}{10}\selectfont\bf}}
\renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
           {12\p@ \@plus 6\p@ \@minus 3\p@}%
           {\p@}%
           {\fontfamily{ptm}\fontsize{10}{10}\selectfont\bf\em}}

%% Page Layout setup (margins)
\setlength{\topmargin}{-0.54cm}
\setlength{\headheight}{20pt}
\setlength{\headsep}{0.6cm}
\setlength{\textheight}{24cm}
\setlength{\textwidth}{16.5cm}
\setlength{\oddsidemargin}{-0.04cm}
\setlength{\evensidemargin}{-0.04cm}
\setlength{\footskip}{10mm}
\setlength{\parindent}{7mm}
\setlength{\parskip}{0mm}

%% Define commands used for final version (publication)
\newcommand{\Volume}[1]{\def\@Volume{#1}}
\newcommand{\Number}[1]{\def\@Number{#1}}
\newcommand{\Year}[1]{\def\@Year{#1}}
\newcommand{\Page}[1]{\setcounter{page}{#1} \def\@Page{#1}}
\newcommand{\DeliveryDate}[1]{\def\@DateDelivered{#1}}

%% Authors - commands
\newcommand{\Author}[5]{\def\@Authora{#1} \def\@Showa{#2} \def\@Initialsa{#3} \def\@Addressa{#4} \def\@EMaila{#5}}
\newcommand{\SecondAuthor}[5]{\def\@Authorb{#1} \def\@Showb{#2} \def\@Initialsb{#3} \def\@Addressb{#4} \def\@EMailb{#5}}
\newcommand{\ThirdAuthor}[5]{\def\@Authorc{#1} \def\@Showc{#2} \def\@Initialsc{#3} \def\@Addressc{#4} \def\@EMailc{#5}}
\newcommand{\FourthAuthor}[5]{\def\@Authord{#1} \def\@Showd{#2} \def\@Initialsd{#3} \def\@Addressd{#4} \def\@EMaild{#5}}
\newcommand{\FifthAuthor}[5]{\def\@Authore{#1} \def\@Showe{#2} \def\@Initialse{#3} \def\@Addresse{#4} \def\@EMaile{#5}}
\newcommand{\SixthAuthor}[5]{\def\@Authorf{#1} \def\@Showf{#2} \def\@Initialsf{#3} \def\@Addressf{#4} \def\@EMailf{#5}}
\newcommand{\SeventhAuthor}[5]{\def\@Authorg{#1} \def\@Showg{#2} \def\@Initialsg{#3} \def\@Addressg{#4} \def\@EMailg{#5}}
\newcommand{\EighthAuthor}[5]{\def\@Authorh{#1} \def\@Showh{#2} \def\@Initialsh{#3} \def\@Addressh{#4} \def\@EMailh{#5}}
\newcommand{\NinethAuthor}[5]{\def\@Authori{#1} \def\@Showi{#2} \def\@Initialsi{#3} \def\@Addressi{#4} \def\@EMaili{#5}}
\newcommand{\TenthAuthor}[5]{\def\@Authorj{#1} \def\@Showj{#2} \def\@Initialsj{#3} \def\@Addressj{#4} \def\@EMailj{#5}}
\newcommand{\LastAuthor}[6]{\def\@Authork{#1} \def\@Showk{#2} \def\@Initialsk{#3} \def\@Addressk{#4} \def\@EMailk{#5} \def\@And{#6}}

%% Authors - list of authors used in header
\def\@Authors{\@Authora\@ifundefined{@Authorb}{}{,\space\@Authorb}\@ifundefined{@Authorc}{}{,\space\@Authorc}\@ifundefined{@Authord}{}{,\space\@Authord}\@ifundefined{@Authore}{}{,\space\@Authore}\@ifundefined{@Authorf}{}{,\space\@Authorf}\@ifundefined{@Authorg}{}{,\space\@Authorg}\@ifundefined{@Authorh}{}{,\space\@Authorh}\@ifundefined{@Authori}{}{,\space\@Authori}\@ifundefined{@Authorj}{}{,\space\@Authorj}\@ifundefined{@Authork}{}{\space{\normalfont\@And}~\@Authork}}

%% Footnotes for authors on title page
\def\@footone{\ifx\@Showa\@empty\else{\footnote{\footnotesize\ifthenelse{\equal{\@Initialsa}{\@empty}}{\textit{\@Authora}}{\textit{\@Initialsa}}\ifthenelse{\equal{\@Addressa}{\@empty}}{}{,\space\@Addressa}\ifthenelse{\equal{\@EMaila}{\@empty}}{}{,\space\href{mailto:\@EMaila}{\underline{\@EMaila}}}}}\fi}
\def\@foottwo{\ifx\@Showb\@empty\else{\footnote{\footnotesize\ifthenelse{\equal{\@Initialsb}{\@empty}}{\textit{\@Authorb}}{\textit{\@Initialsb}}\ifthenelse{\equal{\@Addressb}{\@empty}}{}{,\space\@Addressb}\ifthenelse{\equal{\@EMailb}{\@empty}}{}{,\space\href{mailto:\@EMailb}{\underline{\@EMailb}}}}}\fi}
\def\@footthree{\ifx\@Showc\@empty\else{\footnote{\footnotesize\ifthenelse{\equal{\@Initialsc}{\@empty}}{\textit{\@Authorc}}{\textit{\@Initialsc}}\ifthenelse{\equal{\@Addressc}{\@empty}}{}{,\space\@Addressc}\ifthenelse{\equal{\@EMailc}{\@empty}}{}{,\space\href{mailto:\@EMailc}{\underline{\@EMailc}}}}}\fi}
\def\@footfour{\ifx\@Showd\@empty\else{\footnote{\footnotesize\ifthenelse{\equal{\@Initialsd}{\@empty}}{\textit{\@Authord}}{\textit{\@Initialsd}}\ifthenelse{\equal{\@Addressd}{\@empty}}{}{,\space\@Addressd}\ifthenelse{\equal{\@EMaild}{\@empty}}{}{,\space\href{mailto:\@EMaild}{\underline{\@EMaild}}}}}\fi}
\def\@footfive{\ifx\@Showe\@empty\else{\footnote{\footnotesize\ifthenelse{\equal{\@Initialse}{\@empty}}{\textit{\@Authore}}{\textit{\@Initialse}}\ifthenelse{\equal{\@Addresse}{\@empty}}{}{,\space\@Addresse}\ifthenelse{\equal{\@EMaile}{\@empty}}{}{,\space\href{mailto:\@EMaile}{\underline{\@EMaile}}}}}\fi}
\def\@footsix{\ifx\@Showf\@empty\else{\footnote{\footnotesize\ifthenelse{\equal{\@Initialsf}{\@empty}}{\textit{\@Authorf}}{\textit{\@Initialsf}}\ifthenelse{\equal{\@Addressf}{\@empty}}{}{,\space\@Addressf}\ifthenelse{\equal{\@EMailf}{\@empty}}{}{,\space\href{mailto:\@EMailf}{\underline{\@EMailf}}}}}\fi}
\def\@footseven{\ifx\@Showg\@empty\else{\footnote{\footnotesize\ifthenelse{\equal{\@Initialsg}{\@empty}}{\textit{\@Authorg}}{\textit{\@Initialsg}}\ifthenelse{\equal{\@Addressg}{\@empty}}{}{,\space\@Addressg}\ifthenelse{\equal{\@EMailg}{\@empty}}{}{,\space\href{mailto:\@EMailg}{\underline{\@EMailg}}}}}\fi}
\def\@footeight{\ifx\@Showh\@empty\else{\footnote{\footnotesize\ifthenelse{\equal{\@Initialsh}{\@empty}}{\textit{\@Authorh}}{\textit{\@Initialsh}}\ifthenelse{\equal{\@Addressh}{\@empty}}{}{,\space\@Addressh}\ifthenelse{\equal{\@EMailh}{\@empty}}{}{,\space\href{mailto:\@EMailh}{\underline{\@EMailh}}}}}\fi}
\def\@footnine{\ifx\@Showi\@empty\else{\footnote{\footnotesize\ifthenelse{\equal{\@Initialsi}{\@empty}}{\textit{\@Authori}}{\textit{\@Initialsi}}\ifthenelse{\equal{\@Addressi}{\@empty}}{}{,\space\@Addressi}\ifthenelse{\equal{\@EMaili}{\@empty}}{}{,\space\href{mailto:\@EMaili}{\underline{\@EMaili}}}}}\fi}
\def\@footten{\ifx\@Showj\@empty\else{\footnote{\footnotesize\ifthenelse{\equal{\@Initialsj}{\@empty}}{\textit{\@Authorj}}{\textit{\@Initialsj}}\ifthenelse{\equal{\@Addressj}{\@empty}}{}{,\space\@Addressj}\ifthenelse{\equal{\@EMailj}{\@empty}}{}{,\space\href{mailto:\@EMailj}{\underline{\@EMailj}}}}}\fi}
\def\@footlast{\ifx\@Showk\@empty\else{\footnote{\footnotesize\ifthenelse{\equal{\@Initialsk}{\@empty}}{\textit{\@Authork}}{\textit{\@Initialsk}}\ifthenelse{\equal{\@Addressk}{\@empty}}{}{,\space\@Addressk}\ifthenelse{\equal{\@EMailk}{\@empty}}{}{,\space\href{mailto:\@EMailk}{\underline{\@EMailk}}}}}\fi}

%% Authors - list of authors for titlepage (with footnotes)
\def\@ListOfAuthors{\@Authora\ifx\@footone\@empty\else\hspace{1pt}\@footone\fi\@ifundefined{@Authorb}{}{, \@Authorb\ifx\@foottwo\@empty\else\hspace{1pt}\@foottwo\fi}\@ifundefined{@Authorc}{}{, \@Authorc\ifx\@footthree\@empty\else\hspace{1pt}\@footthree\fi}\@ifundefined{@Authord}{}{, \@Authord\ifx\@footfour\@empty\else\hspace{1pt}\@footfour\fi}\@ifundefined{@Authore}{}{, \@Authore\ifx\@footfive\@empty\else\hspace{1pt}\@footfive\fi}\@ifundefined{@Authorf}{}{, \@Authorf\ifx\@footsix\@empty\else\hspace{1pt}\@footsix\fi}\@ifundefined{@Authorg}{}{, \@Authorg\ifx\@footseven\@empty\else\hspace{1pt}\@footseven\fi}\@ifundefined{@Authorh}{}{, \@Authorh\ifx\@footeight\@empty\else\hspace{1pt}\@footeight\fi}\@ifundefined{@Authori}{}{, \@Authori\ifx\@footnine\@empty\else\hspace{1pt}\@footnine\fi}\@ifundefined{@Authorj}{}{, \@Authorj\ifx\@footten\@empty\else\hspace{1pt}\@footten\fi}\@ifundefined{@Authork}{}{\space{\normalfont\textit{\@And}}~\@Authork\ifx\@footlast\@empty\else\hspace{1pt}\@footlast\fi}}

%% Title page header
\fancypagestyle{fancytitle}{%
\if@Final
	\fancyhead[L]{\fontsize{8}{8}\fontfamily{ptm}\selectfont\textbf{\@Journal}\hspace{15pt} Ro\v cn\' ik\space\textbf{\@Volume}\hspace{2pt} (\@Year),\space\@SpecText\v c\' islo\space\textbf{\@Number},\space\@Page-\pageref{LastPage}}
\else
	\fancyhead[L]{\fontsize{8}{8}\fontfamily{ptm}\selectfont\textbf{Submitted to\space\@Journal},\space\today}
\fi
\fancyfoot[L]{\fontsize{10}{10}\fontfamily{ptm}\selectfont \thepage}
}


%% Title page
\renewcommand\maketitle{
\if@CZ
	\def\figurename{Obr.}\def\tablename{Tab.}
	\else
\fi

\if@SK
	\def\figurename{Obr.}\def\tablename{Tab.}
	\else
\fi
  \begin{center}%
  	\ifthenelse{\isodd{\@Page}}{}{\thispagestyle{fancytitle}}
  	\vspace*{0.4cm}
  	\parbox[c]{0.80\textwidth}{\fontsize{14}{18}\fontfamily{ptm}\selectfont\centering\textbf{\@title}} %Title font size
    \vskip 0.8cm
    \parbox[c]{0.75\textwidth}{\fontsize{10}{10}\fontfamily{ptm}\selectfont\centering\textbf{\textit{\@ListOfAuthors}}} % Authors font size
    \if@Final \let\thefootnote\relax\footnotetext{(Review and revised version\space\@DateDelivered)}\fi
  \end{center}
 }

%% Abstract environment
\newenvironment{Abstract}{
	\noindent
	\hspace*{0.05\textwidth}
	\begin{minipage}{0.90\textwidth}
		\vskip 0.4cm%
		\if@Special
			\begin{centering}
			\fontsize{8}{10}\fontfamily{ptm}
			\textbf{\em \@OtherTitle}\par
			\end{centering}
		\fi
		\fontsize{8}{10}\fontfamily{ptm}\selectfont
		\parindent=7mm
		\begin{it}
}{
		\end{it}\par
	\end{minipage}
}

%% Keywords environment
\newenvironment{Keywords}{
	\par \noindent
	\hspace*{0.05\textwidth}
	\begin{minipage}{0.9\textwidth}
		\vskip 0.3cm
		\small 
		\parindent=0mm
		\fontfamily{ptm} \fontsize{8}{8} \selectfont
		\textbf{\textit{Keywords:}}\begin{it}
}{
		\end{it}
		\parskip=0.0cm
	\end{minipage}
}

% Acknowledgements environment
\newenvironment{Acknowledgement}{
\noindent
	\hspace*{0.5\textwidth}
	\begin{minipage}{0.5\textwidth}
		\vskip 0.4cm%
		\if@Special
			\begin{centering}
			\fontsize{8}{10}\fontfamily{ptm}
			\textbf{\em \if@SK Po\v dakovanie \else Pod\v ekov\' an\' i \fi}\par
			\end{centering}
			\else
			\begin{centering}
			\fontsize{8}{10}\fontfamily{ptm}
			\textbf{\em Acknowledgement}\par
			\end{centering}
		\fi
		\fontsize{8}{10}\fontfamily{ptm}\selectfont
		\parindent=4mm
		\begin{it}
}{
	\end{it}
		\parskip=0.0cm
	\end{minipage}
}

%% Header and footer
\pagestyle{fancy}
\pagenumbering{arabic}
\fancyhead{}
\fancyfoot{}
\if@Special
	\def\@SpecText{mimoriadne\space}
\else
	\def\@SpecText{}
\fi
\if@Final
	\fancyhead[RO]{\fontsize{8}{8}\fontfamily{ptm}\selectfont\textbf{\@Journal}\hspace{15pt} Ro\v cn\' ik\space\textbf{\@Volume}\hspace{2pt} (\@Year),\space\@SpecText\v c\' islo\space\textbf{\@Number},\space\@Page-\pageref{LastPage}}
\else
	\fancyhead[RO]{\fontsize{8}{8}\fontfamily{ptm}\selectfont\textbf{Submitted to\space\@Journal},\space\today}
\fi

\AtBeginDocument{ %Check if header on even pages is too long and if so, compress the names of authors (et. al)
	\maketitle
	\newlength{\headtextlength}
	\setlength{\headtextlength}{\widthof{\fontsize{8}{8}\fontfamily{ptm}\selectfont \textbf{\@Authors}:\fontsize{8}{8}\fontfamily{ptm}\selectfont\space\@title}}
	\ifthenelse{\lengthtest{\textwidth > \headtextlength}}{\fancyhead[LE]{\fontsize{8}{8}\fontfamily{ptm}\selectfont \textbf{\@Authors}:\fontsize{8}{8}\fontfamily{ptm}\selectfont\space\@title}}{\ifthenelse{\equal{\@Authora}{\@Authors}}{\fancyhead[LE]{\fontsize{8}{8}\fontfamily{ptm}\selectfont \textbf{\@Authors}:\fontsize{8}{8}\fontfamily{ptm}\selectfont\space\@title}}{\fancyhead[LE]{\fontsize{8}{8}\fontfamily{ptm}\selectfont \textbf{\@Authora}{ et al.:}\fontsize{8}{8}\fontfamily{ptm}\selectfont\space\@title}}}
}

\fancyfoot[RO, LE]{\fontsize{10}{10}\fontfamily{ptm}\selectfont \thepage}
\renewcommand{\headrulewidth}{0.5pt}
\renewcommand{\footrulewidth}{0pt}

%% End of Code (finaly)

%% This part consists of copied code from different packages - see headers for details.


%% ----------------------------------------------------------------------------------------------------------------------

%%
%% This is file `mathptmx.sty',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% psfonts.dtx  (with options: `mathptmx')
%% 
%% IMPORTANT NOTICE:
%% 
%% For the copyright see the source file.
%% 
%% Any modified versions of this file must be renamed
%% with new filenames distinct from mathptmx.sty.
%% 
%% For distribution of the original source see the terms
%% for copying and modification in the file psfonts.dtx.
%% 
%% This generated file may be distributed as long as the
%% original source files, as listed above, are part of the
%% same distribution. (The sources need not necessarily be
%% in the same archive or directory.)
%\ProvidesPackage{mathptmx}%
%[2005/04/12 PSNFSS-v9.2a
%Times w/ Math, improved (SPQR, WaS)
%]
\def\rmdefault{ptm}
\DeclareSymbolFont{operators}   {OT1}{ztmcm}{m}{n}
\DeclareSymbolFont{letters}     {OML}{ztmcm}{m}{it}
\DeclareSymbolFont{symbols}     {OMS}{ztmcm}{m}{n}
\DeclareSymbolFont{largesymbols}{OMX}{ztmcm}{m}{n}
\DeclareSymbolFont{bold}        {OT1}{ptm}{bx}{n}
\DeclareSymbolFont{italic}      {OT1}{ptm}{m}{it}
\@ifundefined{mathbf}{}{\DeclareMathAlphabet{\mathbf}{OT1}{ptm}{bx}{n}}
\@ifundefined{mathit}{}{\DeclareMathAlphabet{\mathit}{OT1}{ptm}{m}{it}}
\DeclareMathSymbol{\omicron}{0}{operators}{`\o}
\renewcommand{\jmath}{%
  \PackageError
 {mathptmx}
  {The symbols \protect\jmath, \protect\amalg\space and
  \protect\coprod\MessageBreak
  are not available with this package}
  {Type \space <return> \space to proceed;
  your command will be ignored.}}
\let\amalg=\jmath
\let\coprod=\jmath
\thinmuskip=2mu
\medmuskip=2.5mu plus 1mu minus 1mu
\thickmuskip=4mu plus 1.5mu minus 1mu
\DeclareRobustCommand\hbar{{%
 \dimen@.03em%
 \dimen@ii.06em%
 \def\@tempa##1##2{{%
   \lower##1\dimen@\rlap{\kern##1\dimen@ii\the##2 0\char22}}}%
 \mathchoice\@tempa\@ne\textfont
            \@tempa\@ne\textfont
            \@tempa\defaultscriptratio\scriptfont
            \@tempa\defaultscriptscriptratio\scriptscriptfont
  h}}
\def\boldmath{%
   \PackageWarning%
   {mathptmx}%
   {There are no bold math fonts}%
   \global\let\boldmath=\relax
}
\def\defaultscriptratio{.74}
\def\defaultscriptscriptratio{.6}
\DeclareMathSizes{5}{5}{5}{5}
\DeclareMathSizes{6}{6}{5}{5}
\DeclareMathSizes{7}{7}{5}{5}
\DeclareMathSizes{8}{8}{6}{5}
\DeclareMathSizes{9}{9}{7}{5}
\DeclareMathSizes{10}{10}{7.4}{6}
\DeclareMathSizes{10.95}{10.95}{8}{6}
\DeclareMathSizes{12}{12}{9}{7}
\DeclareMathSizes{14.4}{14.4}{10.95}{8}
\DeclareMathSizes{17.28}{17.28}{12}{10}
\DeclareMathSizes{20.74}{20.74}{14.4}{12}
\DeclareMathSizes{24.88}{24.88}{17.28}{14.4}
%\DeclareOption{slantedGreek}{%
%  \DeclareMathSymbol{\Gamma}{\mathalpha}{letters}{0}
%  \DeclareMathSymbol{\Delta}{\mathalpha}{letters}{1}
%  \DeclareMathSymbol{\Theta}{\mathalpha}{letters}{2}
%  \DeclareMathSymbol{\Lambda}{\mathalpha}{letters}{3}
%  \DeclareMathSymbol{\Xi}{\mathalpha}{letters}{4}
%  \DeclareMathSymbol{\Pi}{\mathalpha}{letters}{5}
%  \DeclareMathSymbol{\Sigma}{\mathalpha}{letters}{6}
%  \DeclareMathSymbol{\Upsilon}{\mathalpha}{letters}{7}
%  \DeclareMathSymbol{\Phi}{\mathalpha}{letters}{8}
%  \DeclareMathSymbol{\Psi}{\mathalpha}{letters}{9}
%  \DeclareMathSymbol{\Omega}{\mathalpha}{letters}{10}
%}
\DeclareMathSymbol{\upGamma}{\mathord}{operators}{0}
\DeclareMathSymbol{\upDelta}{\mathord}{operators}{1}
\DeclareMathSymbol{\upTheta}{\mathord}{operators}{2}
\DeclareMathSymbol{\upLambda}{\mathord}{operators}{3}
\DeclareMathSymbol{\upXi}{\mathord}{operators}{4}
\DeclareMathSymbol{\upPi}{\mathord}{operators}{5}
\DeclareMathSymbol{\upSigma}{\mathord}{operators}{6}
\DeclareMathSymbol{\upUpsilon}{\mathord}{operators}{7}
\DeclareMathSymbol{\upPhi}{\mathord}{operators}{8}
\DeclareMathSymbol{\upPsi}{\mathord}{operators}{9}
\DeclareMathSymbol{\upOmega}{\mathord}{operators}{10}
\ProcessOptions\relax
\let\s@vedhbar\hbar
\AtBeginDocument{%
  \DeclareFontFamily{U}{msa}{}%
  \DeclareFontShape{U}{msa}{m}{n}{<->msam10}{}%
  \DeclareFontFamily{U}{msb}{}%
  \DeclareFontShape{U}{msb}{m}{n}{<->msbm10}{}%
  \DeclareFontFamily{U}{euf}{}%
  \DeclareFontShape{U}{euf}{m}{n}{<-6>eufm5<6-8>eufm7<8->eufm10}{}%
  \DeclareFontShape{U}{euf}{b}{n}{<-6>eufb5<6-8>eufb7<8->eufb10}{}%
  \@ifpackageloaded{amsfonts}{\let\hbar\s@vedhbar}{}
  \@ifpackageloaded{amsmath}{}{%
    \newdimen\big@size
    \addto@hook\every@math@size{\setbox\z@\vbox{\hbox{$($}\kern\z@}%
       \global\big@size 1.2\ht\z@}
    \def\bBigg@#1#2{%
       {\hbox{$\left#2\vcenter to#1\big@size{}\right.\n@space$}}}
    \def\big{\bBigg@\@ne}
    \def\Big{\bBigg@{1.5}}
    \def\bigg{\bBigg@\tw@}
    \def\Bigg{\bBigg@{2.5}}
  }
}
%\endinput
%%
%% End of file `mathptmx.sty'.

%% ------------------------------------------------------------------------------------------------------------

%%
%% This is file `footnote.sty',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% footnote.dtx  (with options: `package')
%% 
%% IMPORTANT NOTICE
%%
%% footnote package -- Save footnotes around boxing environments
%% Copyright (c) 1996 Mark Wooding
%%
%% This program is free software; you can redistribute it and/or modify
%% it under the terms of the GNU General Public License as published by
%% the Free Software Foundation; either version 2 of the License, or
%% (at your option) any later version.
%%
%% This program is distributed in the hope that it will be useful,
%% but WITHOUT ANY WARRANTY; without even the implied warranty of
%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%% GNU General Public License for more details.
%%
%% You should have received a copy of the GNU General Public License
%% along with this program; if not, write to the Free Software
%% Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
%%
%\NeedsTeXFormat{LaTeX2e}
%\ProvidesPackage{footnote}
%                [1997/01/28 1.13 Save footnotes around boxes]
%% \CharacterTable
%%  {Upper-case    \A\B\C\D\E\F\G\H\I\J\K\L\M\N\O\P\Q\R\S\T\U\V\W\X\Y\Z
%%   Lower-case    \a\b\c\d\e\f\g\h\i\j\k\l\m\n\o\p\q\r\s\t\u\v\w\x\y\z
%%   Digits        \0\1\2\3\4\5\6\7\8\9
%%   Exclamation   \!     Double quote  \"     Hash (number) \#
%%   Dollar        \$     Percent       \%     Ampersand     \&
%%   Acute accent  \'     Left paren    \(     Right paren   \)
%%   Asterisk      \*     Plus          \+     Comma         \,
%%   Minus         \-     Point         \.     Solidus       \/
%%   Colon         \:     Semicolon     \;     Less than     \<
%%   Equals        \=     Greater than  \>     Question mark \?
%%   Commercial at \@     Left bracket  \[     Backslash     \\
%%   Right bracket \]     Circumflex    \^     Underscore    \_
%%   Grave accent  \`     Left brace    \{     Vertical bar  \|
%%   Right brace   \}     Tilde         \~}
%%
\ifx\fn@notes\@@undefined%
  \newbox\fn@notes%
\fi
\newdimen\fn@width
\let\fn@colwidth\columnwidth
\newif\if@savingnotes
\def\fn@startnote{%
  \hsize\fn@colwidth%
  \interlinepenalty\interfootnotelinepenalty%
  \reset@font\footnotesize%
  \floatingpenalty\@MM% Is this right???
  \@parboxrestore%
  \protected@edef\@currentlabel{\csname p@\@mpfn\endcsname\@thefnmark}%
  \color@begingroup%
}
\let\fn@endnote\color@endgroup
\def\fn@fntext#1{%
  \ifx\ifmeasuring@\@@undefined%
    \expandafter\@secondoftwo\else\expandafter\@iden%
  \fi%
  {\ifmeasuring@\expandafter\@gobble\else\expandafter\@iden\fi}%
  {%
    \global\setbox\fn@notes\vbox{%
      \unvbox\fn@notes%
      \fn@startnote%
      \@makefntext{%
        \rule\z@\footnotesep%
        \ignorespaces%
        #1%
        \@finalstrut\strutbox%
      }%
      \fn@endnote%
    }%
  }%
}
\def\savenotes{%
  \begingroup%
  \if@savingnotes\else%
    \@savingnotestrue%
    \let\@footnotetext\fn@fntext%
    \let\@mpfootnotetext\fn@fntext%
    \fn@width\columnwidth%
    \let\fn@colwidth\fn@width%
    \global\setbox\fn@notes\box\voidb@x%
    \let\fn@thempfn\thempfn%
    \let\fn@mpfn\@mpfn%
    \ifx\@minipagerestore\relax\let\@minipagerestore\@empty\fi%
    \expandafter\def\expandafter\@minipagerestore\expandafter{%
      \@minipagerestore%
      \let\thempfn\fn@thempfn%
      \let\@mpfn\fn@mpfn%
    }%
  \fi%
}
\def\spewnotes{%
  \endgroup%
  \if@savingnotes\else\ifvoid\fn@notes\else\begingroup%
    \let\@makefntext\@empty%
    \let\@finalstrut\@gobble%
    \let\rule\@gobbletwo%
    \@footnotetext{\unvbox\fn@notes}%
  \endgroup\fi\fi%
}
\let\endsavenotes\spewnotes
\def\fn@getmark#1#2{%
  \begingroup%
  \@ifnextchar[%
    {\fn@getmark@i{#1}}%
    {#1\fn@getmark@ii{#2}}%
}
\def\fn@getmark@i#1[#2]{%
  \csname c@\@mpfn\endcsname#2%
  \fn@getmark@ii%
}
\def\fn@getmark@ii#1{%
  \unrestored@protected@xdef\@thefnmark{\thempfn}%
  \endgroup%
  #1%
}
\def\fn@startfntext{%
  \setbox\z@\vbox\bgroup%
    \fn@startnote%
    \fn@prefntext%
    \rule\z@\footnotesep%
    \ignorespaces%
}
\def\fn@endfntext{%
    \@finalstrut\strutbox%
    \fn@postfntext%
  \egroup%
  \begingroup%
    \let\@makefntext\@empty%
    \let\@finalstrut\@gobble%
    \let\rule\@gobbletwo%
    \@footnotetext{\unvbox\z@}%
  \endgroup%
}
\let\fn@latex@@footnote\footnote
\def\fn@footnote{footnote}
\def\footnote{%
  \ifx\@currenvir\fn@footnote%
    \expandafter\@firstoftwo%
  \else%
    \expandafter\@secondoftwo%
  \fi%
  {\fn@getmark{\stepcounter\@mpfn}%
              {\leavevmode\unskip\@footnotemark\fn@startfntext}}%
  {\fn@latex@@footnote}%
}
\let\endfootnote\fn@endfntext
\def\fn@footnotetext{footnotetext}
\let\fn@latex@@footnotetext\footnotetext
\def\footnotetext{%
  \ifx\@currenvir\fn@footnotetext%
    \expandafter\@firstoftwo%
  \else%
    \expandafter\@secondoftwo%
  \fi%
  {\fn@getmark{}\fn@startfntext}%
  {\fn@latex@@footnotetext}%
}
\let\endfootnotetext\endfootnote
\long\def\@tempa#1\@@#2\@@@{\def\fn@prefntext{#1}\def\fn@postfntext{#2}}
\expandafter\@tempa\@makefntext\@@\@@@
\def\makesavenoteenv{\@ifnextchar[\fn@msne@ii\fn@msne@i}
\def\fn@msne@i#1{%
  \expandafter\let\csname msne$#1\expandafter\endcsname%$
                  \csname #1\endcsname%
  \expandafter\let\csname endmsne$#1\expandafter\endcsname%$
                  \csname end#1\endcsname%
  \fn@msne@ii[#1]{msne$#1}%$
}
\def\fn@msne@ii[#1]#2{%
  \expandafter\edef\csname#1\endcsname{%
    \noexpand\savenotes%
    \expandafter\noexpand\csname#2\endcsname%
  }%
  \expandafter\edef\csname end#1\endcsname{%
    \expandafter\noexpand\csname end#2\endcsname%
    \noexpand\expandafter%
    \noexpand\spewnotes%
    \noexpand\if@endpe\noexpand\@endpetrue\noexpand\fi%
  }%
}
\makesavenoteenv[minipage*]{minipage}
\let\fn@parbox\parbox
\def\parbox{\@ifnextchar[{\fn@parbox@i{}}{\fn@parbox@ii{}}}
\def\fn@parbox@i#1[#2]{%
  \@ifnextchar[{\fn@parbox@i{#1[#2]}}{\fn@parbox@ii{#1[#2]}}%
}
\long\def\fn@parbox@ii#1#2#3{\savenotes\fn@parbox#1{#2}{#3}\spewnotes}
%\endinput

%% ------------------------------------------------------------------------------------------------------------

%%
%% End of file `footnote.sty'.

%%
%% This is file `calc.sty',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% calc.dtx  (with options: `package')
%% 
%% This is a generated file.
%% 
%% Copyright 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005
%% 2006 2008 2009
%% The LaTeX3 Project and any individual authors listed elsewhere
%% in this file.
%% 
%% This file was generated from file(s) of the Standard LaTeX `Tools Bundle'.
%% --------------------------------------------------------------------------
%% 
%% It may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3c
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%    http://www.latex-project.org/lppl.txt
%% and version 1.3c or later is part of all distributions of LaTeX
%% version 2005/12/01 or later.
%% 
%% This file may only be distributed together with a copy of the LaTeX
%% `Tools Bundle'. You may however distribute the LaTeX `Tools Bundle'
%% without such generated files.
%% 
%% The list of all files belonging to the LaTeX `Tools Bundle' is
%% given in the file `manifest.txt'.
%% 
%% File `calc.dtx'.
%% Copyright (C) 1992--1995
%%          Kresten Krab Thorup and Frank Jensen.
%% Copyright (C) 1997--2007
%%          Kresten Krab Thorup, Frank Jensen and the LaTeX3 Project.
%%
%% The original authors (fj@hugin.dk and  krab@daimi.aau.dk) have
%% contributed this package to the LaTeX distribution.
%% Problems with this package should now be sent using latexbug.tex to
%% the normal LaTeX bug report address.
%\NeedsTeXFormat{LaTeX2e}
%\ProvidesPackage{calc}
%          [2007/08/22 v4.3 Infix arithmetic (KKT,FJ)]
\def\calc@assign@generic#1#2#3#4{\let\calc@A#1\let\calc@B#2%
    \calc@open(#4!%
    \global\calc@A\calc@B\endgroup#3\calc@B}
\def\calc@assign@count{\calc@assign@generic\calc@Acount\calc@Bcount}
\def\calc@assign@dimen{\calc@assign@generic\calc@Adimen\calc@Bdimen}
\def\calc@assign@skip{\calc@assign@generic\calc@Askip\calc@Bskip}
\newcount\calc@Acount   \newcount\calc@Bcount
\newdimen\calc@Adimen   \newdimen\calc@Bdimen
\newskip\calc@Askip     \newskip\calc@Bskip
\def\setcounter#1#2{\@ifundefined{c@#1}{\@nocounterr{#1}}%
   {\calc@assign@count{\global\csname c@#1\endcsname}{#2}}}
  \def\addtocounter#1#2{\@ifundefined{c@#1}{\@nocounterr{#1}}%
    {\calc@assign@count{\global\advance\csname c@#1\endcsname}{#2}}}%
  \def\stepcounter#1{\@ifundefined {c@#1}%
    {\@nocounterr {#1}}%
    {\global\advance\csname c@#1\endcsname \@ne
    \begingroup
      \let\@elt\@stpelt \csname cl@#1\endcsname
    \endgroup}}%
\@ifpackageloaded{amstext}{%
 \expandafter\def\expandafter\stepcounter
    \expandafter#\expandafter1\expandafter{%
    \expandafter\iffirstchoice@\stepcounter{#1}\fi
 }
 \expandafter\def\expandafter\addtocounter
    \expandafter#\expandafter1\expandafter#\expandafter2\expandafter{%
    \expandafter\iffirstchoice@\addtocounter{#1}{#2}\fi
 }
}{}
\DeclareRobustCommand\setlength{\calc@assign@skip}
\DeclareRobustCommand\addtolength[1]{\calc@assign@skip{\advance#1}}
\def\calc@pre@scan#1{%
  \expandafter\@calc@pre@scan\romannumeral-`\a#1}
\def\@calc@pre@scan#1{%
  \ifx(#1%
    \expandafter\calc@open
  \else
    \ifx\widthof#1%
      \expandafter\expandafter\expandafter\calc@textsize
    \else
      \ifx\maxof#1%
        \expandafter\expandafter\expandafter\expandafter
        \expandafter\expandafter\expandafter\calc@maxmin@addsub
      \else
        \calc@numeric% no \expandafter needed for this one.
      \fi
    \fi
  \fi
  #1}
\def\calc@open({\begingroup\aftergroup\calc@initB
   \begingroup\aftergroup\calc@initB
   \calc@pre@scan}
\def\calc@initB{\calc@B\calc@A}
\def\calc@numeric{\afterassignment\calc@post@scan \global\calc@A}
\@for\reserved@a:=widthof,heightof,depthof,totalheightof,maxof,minof\do
{\@ifundefined{\reserved@a}{}{%
  \PackageError{calc}{%
  The\space calc\space package\space reserves\space the\space
  command\space name\space `\@backslashchar\reserved@a'\MessageBreak
  but\space it\space has\space already\space been\space defined\space
  with\space the\space meaning\MessageBreak
  `\expandafter\meaning\csname\reserved@a\endcsname'.\MessageBreak
  This\space original\space definition\space will\space be\space lost}%
  {If\space you\space need\space a\space command\space with\space
  this\space definition,\space you\space must\space use\space a\space
  different\space name.}}%
}
\let\widthof\ignorespaces
\let\heightof\ignorespaces
\let\depthof\ignorespaces
\let\totalheightof\ignorespaces
\def\calc@textsize #1#2{%
  \begingroup
    \let\widthof\wd
    \let\heightof\ht
    \let\depthof\dp
    \def\totalheightof{\ht\dp}%
    \expandafter\@settodim\expandafter{#1}%
      {\global\calc@A}%
      {%
       \let\widthof\ignorespaces
       \let\heightof\ignorespaces
       \let\depthof\ignorespaces
       \let\totalheightof\ignorespaces
       #2}%
  \endgroup
  \calc@post@scan}
\def\calc@post@scan#1{%
 \expandafter\@calc@post@scan\romannumeral-`\a#1}
\def\@calc@post@scan#1{%
  \ifx#1!\let\calc@next\endgroup \else
    \ifx#1+\let\calc@next\calc@add \else
      \ifx#1-\let\calc@next\calc@subtract \else
        \ifx#1*\let\calc@next\calc@multiplyx \else
          \ifx#1/\let\calc@next\calc@dividex \else
            \ifx#1)\let\calc@next\calc@close \else
              \ifx#1\relax\let\calc@next\calc@post@scan \else
                \def\calc@next{\calc@error#1}%
              \fi
            \fi
          \fi
        \fi
      \fi
    \fi
  \fi
  \calc@next}
\def\calc@add{\calc@generic@add\calc@addAtoB}
\def\calc@subtract{\calc@generic@add\calc@subtractAfromB}
\def\calc@generic@add#1{\endgroup\global\calc@A\calc@B\endgroup
   \begingroup\aftergroup#1\begingroup\aftergroup\calc@initB
   \calc@pre@scan}
\def\calc@addAtoB{\advance\calc@B\calc@A}
\def\calc@subtractAfromB{\advance\calc@B-\calc@A}
\ifx\real\@undefined\let\real\relax\fi
\ifx\ratio\@undefined\let\ratio\relax\fi
\def\calc@ratio@x{\ratio}
\def\calc@real@x{\real}
\def\calc@multiplyx#1{\def\calc@tmp{#1}%
  \ifx\calc@tmp\calc@ratio@x \let\calc@next\calc@ratio@multiply \else
    \ifx\calc@tmp\calc@real@x \let\calc@next\calc@real@multiply \else
      \ifx\maxof#1\let\calc@next\calc@maxmin@multiply \else
        \let\calc@next\calc@multiply
      \fi
    \fi
  \fi
  \calc@next#1}
\def\calc@dividex#1{\def\calc@tmp{#1}%
  \ifx\calc@tmp\calc@ratio@x \let\calc@next\calc@ratio@divide \else
    \ifx\calc@tmp\calc@real@x \let\calc@next\calc@real@divide \else
      \ifx\maxof#1\let\calc@next\calc@maxmin@divide \else
        \let\calc@next\calc@divide
      \fi
    \fi
  \fi
  \calc@next#1}
\def\calc@multiply{\calc@generic@multiply\calc@multiplyBbyA}
\def\calc@divide{\calc@generic@multiply\calc@divideBbyA}
\def\calc@generic@multiply#1{\endgroup\begingroup
   \let\calc@A\calc@Acount \let\calc@B\calc@Bcount
   \aftergroup#1\calc@pre@scan}
\def\calc@multiplyBbyA{\multiply\calc@B\calc@Acount}
\def\calc@divideBbyA{\divide\calc@B\calc@Acount}
\def\calc@close
   {\endgroup\global\calc@A\calc@B
    \endgroup\global\calc@A\calc@B
    \calc@post@scan}
\def\calc@ratio@multiply\ratio{\calc@ratio@evaluate}
\def\calc@ratio@divide\ratio#1#2{\calc@ratio@evaluate{#2}{#1}}
\newcount\calc@Ccount
\let\calc@numerator=\calc@Bcount
\let\calc@denominator=\calc@Ccount
\def\calc@ratio@evaluate#1#2{%
   \endgroup\begingroup
      \calc@assign@dimen\calc@numerator{#1}%
      \calc@assign@dimen\calc@denominator{#2}%
      \gdef\calc@the@ratio{}%
      \ifnum\calc@numerator<0 \calc@numerator-\calc@numerator
         \gdef\calc@the@ratio{-}%
      \fi
      \ifnum\calc@denominator<0 \calc@denominator-\calc@denominator
         \xdef\calc@the@ratio{\calc@the@ratio-}%
      \fi
      \calc@Acount\calc@numerator
      \divide\calc@Acount\calc@denominator
      \xdef\calc@the@ratio{\calc@the@ratio\number\calc@Acount.}%
      \calc@next@digit \calc@next@digit \calc@next@digit
      \calc@next@digit \calc@next@digit \calc@next@digit
   \endgroup
   \calc@multiply@by@real\calc@the@ratio
   \begingroup
   \calc@post@scan}
\def\calc@next@digit{%
      \multiply\calc@Acount\calc@denominator
      \advance\calc@numerator -\calc@Acount
      \multiply\calc@numerator 10
      \calc@Acount\calc@numerator
      \divide\calc@Acount\calc@denominator
      \xdef\calc@the@ratio{\calc@the@ratio\number\calc@Acount}}
\def\calc@multiply@by@real#1{\calc@Bdimen #1\calc@B \calc@B\calc@Bdimen}
\def\calc@real@multiply\real#1{\endgroup
   \calc@multiply@by@real{#1}\begingroup
   \calc@post@scan}
\def\calc@real@divide\real#1{\calc@ratio@evaluate{1pt}{#1pt}}
\let\maxof\@@italiccorr
\let\minof\@@italiccorr
\newskip\calc@Cskip
\newif\ifcalc@count@
\def\calc@maxmin@addsub#1#2#3{\begingroup
  \ifx\calc@A\calc@Acount%
    \calc@count@true
  \else
    \calc@count@false
  \fi
  \calc@maxmin@generic#1{#2}{#3}%
  \endgroup
  \calc@post@scan
}
\def\calc@maxmin@generic#1#2#3{%
  \begingroup
    \ifcalc@count@
      \calc@assign@count\calc@Ccount{#2}%
      \calc@assign@count\calc@Bcount{#3}%
      \def\minof{<}\def\maxof{>}%
      \global\calc@A\ifnum\calc@Ccount#1\calc@Bcount
        \calc@Ccount\else\calc@Bcount\fi
    \else
      \calc@assign@skip\calc@Cskip{#2}%
      \calc@assign@skip\calc@Bskip{#3}%
      \def\minof{<}\def\maxof{>}%
      \global\calc@A\ifdim\calc@Cskip#1\calc@Bskip
        \calc@Cskip\else\calc@Bskip\fi
    \fi
  \endgroup
}
\def\calc@maxmin@divmul#1#2#3#4{%
  \endgroup\begingroup
  \calc@count@true
  \aftergroup#1%
  \calc@maxmin@generic#2{#3}{#4}%
  \endgroup\begingroup
  \calc@post@scan
}
\def\calc@maxmin@multiply{\calc@maxmin@divmul\calc@multiplyBbyA}
\def\calc@maxmin@divide  {\calc@maxmin@divmul\calc@divideBbyA}
\def\calc@error#1{%
   \PackageError{calc}%
     {`#1' invalid at this point}%
     {I expected to see one of: + - * / )}}
\def\@settodim#1#2#3{%
  \setbox\@tempboxa\hbox{{#3}}%
  \dimen@ii=\z@
  \@tf@r\reserved@a #1\do{%
  \advance\dimen@ii\reserved@a\@tempboxa}%
  #2=\dimen@ii
  \setbox\@tempboxa\box\voidb@x}
\def\settototalheight{\@settodim{\ht\dp}}
%\endinput
%%
%% End of file `calc.sty'.